@@ -89,8 +89,6 @@ public final class RecordSet extends AbstractRecordSet {
 	protected double														maxValue												= Integer.MIN_VALUE;
 	protected double														minValue												= Integer.MAX_VALUE;
 
-	// for compare set x min/max and y max (time) might be different
-	boolean												isCompareSet									= false;
 	boolean												isUtilitySet									= false;
 	double												maxTime												= 0.0;																																																									//compare set -> each record will have its own timeSteps_ms,
 	// so the biggest record in view point of time will define the time scale
@@ -515,6 +513,7 @@ public final class RecordSet extends AbstractRecordSet {
 	 * @return formatted values as string array including time
 	 */
 	public String[] getExportRow(int index, boolean isAbsolute) {
+		index = this.get(0).getIndex(index);
 		String[] exportRow = new String[this.size() + 1]; // add time column
 		exportRow[0] = this.getFormatedTime_sec(index, isAbsolute);
 		return this.device.prepareExportRow(this, exportRow, index);
@@ -526,6 +525,7 @@ public final class RecordSet extends AbstractRecordSet {
 	 * @return raw values as string array including time
 	 */
 	public String[] getRawExportRow(int index, boolean isAbsolute) {
+		index = this.get(0).getIndex(index);
 		String[] exportRow = new String[this.size() + 1]; // add time column
 		exportRow[0] = this.getFormatedTime_sec(index, isAbsolute);
 		return this.device.prepareRawExportRow(this, exportRow, index);
@@ -1245,13 +1245,6 @@ public final class RecordSet extends AbstractRecordSet {
 		return this.maxTime;
 	}
 
-	/**
-	 * @return the isCompareSet
-	 */
-	public boolean isCompareSet() {
-		return this.isCompareSet;
-	}
-
 	/**
 	 * @return the isZoomMode
 	 */
@@ -1983,9 +1976,11 @@ public final class RecordSet extends AbstractRecordSet {
 				if (oldRecord != null && !oldRecord.equals(record)) {
 					oldRecord.setMeasurementMode(false);
 					oldRecord.setDeltaMeasurementMode(false);
+					oldRecord.setAvgMedianMeasurementMode(false);
 				}
 				this.recordKeyMeasurement = recordKey;
 				record.setDeltaMeasurementMode(false);
+				record.setAvgMedianMeasurementMode(false);
 			}
 		}
 	}
@@ -2003,9 +1998,33 @@ public final class RecordSet extends AbstractRecordSet {
 				if (oldRecord != null && !oldRecord.equals(record)) {
 					oldRecord.setMeasurementMode(false);
 					oldRecord.setDeltaMeasurementMode(false);
+					oldRecord.setAvgMedianMeasurementMode(false);
 				}
 				this.recordKeyMeasurement = recordKey;
 				record.setMeasurementMode(false);
+				record.setAvgMedianMeasurementMode(false);
+			}
+		}
+	}
+
+	/**
+	 * @param recordKey the key which record should be measured
+	 * @param enabled the boolean value to set
+	 */
+	public void setAvgMedianMeasurementMode(String recordKey, boolean enabled) {
+		Record record = this.get(recordKey);
+		if (record != null) {
+			record.setAvgMedianMeasurementMode(enabled);
+			if (enabled) {
+				Record oldRecord = this.get(this.recordKeyMeasurement);
+				if (oldRecord != null && !oldRecord.equals(record)) {
+					oldRecord.setMeasurementMode(false);
+					oldRecord.setDeltaMeasurementMode(false);
+					oldRecord.setAvgMedianMeasurementMode(false);
+				}
+				this.recordKeyMeasurement = recordKey;
+				record.setMeasurementMode(false);
+				record.setDeltaMeasurementMode(false);
 			}
 		}
 	}
@@ -2018,6 +2037,7 @@ public final class RecordSet extends AbstractRecordSet {
 		if (record != null) {
 			record.setMeasurementMode(false);
 			record.setDeltaMeasurementMode(false);
+			record.setAvgMedianMeasurementMode(false);
 		}
 	}
 
@@ -2037,12 +2057,21 @@ public final class RecordSet extends AbstractRecordSet {
 		return this.get(recordKey) != null ? this.get(recordKey).isDeltaMeasurementMode() : false;
 	}
 
+	/**
+	 * @param recordKey the key which record should be measured
+	 * @return the isAvgMedianMeasurementMode (average & median calculation)
+	 */
+	public boolean isAvgMedianMeasurementMode(String recordKey) {
+		return this.get(recordKey) != null ? this.get(recordKey).isAvgMedianMeasurementMode() : false;
+	}
+
 	/**
 	 * Reset the record set in viewpoint of measurement.
 	 */
 	public void resetMeasurement() {
 		this.setMeasurementMode(this.recordKeyMeasurement, false);
 		this.setDeltaMeasurementMode(this.recordKeyMeasurement, false);
+		this.setAvgMedianMeasurementMode(this.recordKeyMeasurement, false);
 	}
 
 	/**
